@@ -4,15 +4,13 @@ from django.contrib.postgres.search import SearchQuery
 from django.db.models import fields as db_fields
 from django.db.models.expressions import F, Func
 from django_filters import filters
-from django_filters.rest_framework import DjangoFilterBackend
 from drf_spectacular.utils import extend_schema
 from rest_framework import mixins, serializers, viewsets
 from rest_framework.decorators import action
-from rest_framework.filters import OrderingFilter
 from rest_framework.parsers import FormParser, MultiPartParser
 from rest_framework.serializers import ValidationError as DRFValidationError
 
-from pulpcore.plugin.actions import ModifyRepositoryActionMixin
+from pulpcore.plugin.actions import ModifyRepositoryActionMixin, raise_for_unknown_content_units
 from pulpcore.plugin.exceptions import DigestValidationError
 from pulpcore.plugin.models import PulpTemporaryFile, RepositoryVersion
 from pulpcore.plugin.serializers import AsyncOperationResponseSerializer
@@ -183,7 +181,6 @@ class CollectionVersionViewSet(SingleArtifactContentUploadViewSet, UploadGalaxyC
     queryset = CollectionVersion.objects.prefetch_related("_artifacts")
     serializer_class = CollectionVersionSerializer
     filterset_class = CollectionVersionFilter
-    filter_backends = (OrderingFilter, DjangoFilterBackend)
     ordering_fields = ("pulp_created", "name", "version", "namespace")
 
     @extend_schema(
@@ -357,7 +354,7 @@ class AnsibleRepositoryViewSet(RepositoryViewSet, ModifyRepositoryActionMixin):
                 content_units[NamedModelViewSet.extract_pk(url)] = url
             content_units_pks = list(content_units.keys())
             existing_content_units = CollectionVersion.objects.filter(pk__in=content_units_pks)
-            self.verify_content_units(existing_content_units, content_units)
+            raise_for_unknown_content_units(existing_content_units, content_units)
 
         result = dispatch(
             sign,
